@@ -12,7 +12,7 @@ __linkedin__ = "https://linkedin.com/in/juste-elysee-malandila"
 
 from .validator import Validator, Field
 from .schema import schema
-from .sanitizer import sanitize
+from .sanitizer import sanitize, strip_html, normalize_whitespace, truncate
 from .exceptions import ValidationError, IntegriumError
 
 __all__ = [
@@ -20,6 +20,9 @@ __all__ = [
     "Field", 
     "schema",
     "sanitize",
+    "strip_html",
+    "normalize_whitespace",
+    "truncate",
     "ValidationError",
     "IntegriumError",
     "__version__",
